@@ -5,9 +5,9 @@ with 'Search::Elasticsearch::Plugin::Watcher::API';
 with 'Search::Elasticsearch::Role::Client::Direct';
 __PACKAGE__->_install_api('watcher');
 
-use Search::Elasticsearch 1.99 ();
+use Search::Elasticsearch 2.00 ();
 
-our $VERSION = '1.99';
+our $VERSION = '2.00';
 
 #===================================
 sub _init_plugin {
@@ -28,7 +28,7 @@ sub _build_watcher {
     shift->_build_namespace('+Search::Elasticsearch::Plugin::Watcher');
 }
 
-1
+1;
 
 =pod
 
@@ -40,7 +40,7 @@ Search::Elasticsearch::Plugin::Watcher - Plugin providing Watcher API for Search
 
 =head1 VERSION
 
-version 1.99
+version 2.00
 
 =head1 SYNOPSIS
 
@@ -68,8 +68,8 @@ In other words, it can be used as follows:
 
     my $response = $es->watcher->info();
 
-It works with the L<version 1.x|Search::Elasticsearch::Client::1_0::Direct>
-and L<version 2.x|Search::Elasticsearch::Client::2_0::Direct> clients, and
+It works with the L<version 1.x|Search::Elasticsearch::Client::2_0::Direct>
+and L<version 2.x|Search::Elasticsearch::Client::1_0::Direct> clients, and
 can be used both in L<Search::Elasticsearch> and in
 L<Search::Elasticsearch::Async>.
 
@@ -88,9 +88,13 @@ L<http://www.elastic.co/guide/en/watcher/current/>
 The C<put_watch()> method is used to register a new watcher or to update
 an existing watcher.
 
-See the L<put_watch docs|http://www.elastic.co/guide/en/watcher/current/api-rest-put-watch.html>
+See the L<put_watch docs|http://www.elastic.co/guide/en/watcher/current/api-rest.html#api-rest-put-watch>
 for more information.
 
+Query string parameters:
+    C<active>,
+    C<master_timeout>
+
 =head2 C<get_watch()>
 
     $response = $es->watcher->get_watch(
@@ -99,7 +103,7 @@ for more information.
 
 The C<get_watch()> method is used to retrieve a watch by ID.
 
-See the L<get_watch docs|http://www.elastic.co/guide/en/watcher/current/api-rest-get-watch.html>
+See the L<get_watch docs|http://www.elastic.co/guide/en/watcher/current/api-rest.html#api-rest-get-watch>
 for more information.
 
 =head2 C<delete_watch()>
@@ -114,7 +118,7 @@ Query string parameters:
     C<force>,
     C<master_timeout>
 
-See the L<delete_watch docs|http://www.elastic.co/guide/en/watcher/current/api-rest-delete-watch.html>
+See the L<delete_watch docs|http://www.elastic.co/guide/en/watcher/current/api-rest.html#api-rest-delete-watch>
 for more information.
 
 =head2 C<execute_watch()>
@@ -131,7 +135,7 @@ Query string parameters:
     C<debug>,
     C<master_timeout>
 
-See the L<execute_watch docs|http://www.elastic.co/guide/en/watcher/current/api-rest-execute-watch.html>
+See the L<execute_watch docs|http://www.elastic.co/guide/en/watcher/current/api-rest.html#api-rest-execute-watch>
 for more information.
 
 =head2 C<ack_watch()>
@@ -147,7 +151,35 @@ a watch.
 Query string parameters:
     C<master_timeout>
 
-See the L<ack_watch docs|http://www.elastic.co/guide/en/watcher/current/api-rest-ack-watch.html>
+See the L<ack_watch docs|http://www.elastic.co/guide/en/watcher/current/api-rest.html#api-rest-ack-watch>
+for more information.
+
+=head2 C<activate_watch()>
+
+    $response = $es->watcher->activate_watch(
+        watch_id => $watch_id,                  # required
+    );
+
+The C<activate_watch()> method is used to activate a deactive watch.
+
+Query string parameters:
+    C<master_timeout>
+
+See the L<activate_watch docs|http://www.elastic.co/guide/en/watcher/current/api-rest.html#api-rest-activate-watch>
+for more information.
+
+=head2 C<deactivate_watch()>
+
+    $response = $es->watcher->deactivate_watch(
+        watch_id => $watch_id,                  # required
+    );
+
+The C<deactivate_watch()> method is used to deactivate an active watch.
+
+Query string parameters:
+    C<master_timeout>
+
+See the L<deactivate_watch docs|http://www.elastic.co/guide/en/watcher/current/api-rest.html#api-rest-deactivate-watch>
 for more information.
 
 =head2 C<info()>
@@ -157,7 +189,7 @@ for more information.
 The C<info()> method returns basic information about the watcher plugin
 that is installed.
 
-See the L<info docs|http://www.elastic.co/guide/en/watcher/current/api-rest-info.html>
+See the L<info docs|http://www.elastic.co/guide/en/watcher/current/api-rest.html#api-rest-info>
 for more information.
 
 =head2 C<stats()>
@@ -168,7 +200,7 @@ for more information.
 
 The C<stats()> method returns information about the status of the watcher plugin.
 
-See the L<stats docs|http://www.elastic.co/guide/en/watcher/current/api-rest-stats.html>
+See the L<stats docs|http://www.elastic.co/guide/en/watcher/current/api-rest.html#api-rest-stats>
 for more information.
 
 =head2 C<stop()>
@@ -177,7 +209,7 @@ for more information.
 
 The C<stop()> method stops the watcher service if it is running.
 
-See the L<stop docs|http://www.elastic.co/guide/en/watcher/current/api-rest-stop.html>
+See the L<stop docs|http://www.elastic.co/guide/en/watcher/current/api-rest.html#api-rest-stop>
 for more information.
 
 =head2 C<start()>
@@ -186,7 +218,7 @@ for more information.
 
 The C<start()> method starts the watcher service if it is not already running.
 
-See the L<start docs|http://www.elastic.co/guide/en/watcher/current/api-rest-start.html>
+See the L<start docs|http://www.elastic.co/guide/en/watcher/current/api-rest.html#api-rest-start>
 for more information.
 
 =head2 C<restart()>
@@ -195,7 +227,7 @@ for more information.
 
 The C<restart()> method stops then starts the watcher service.
 
-See the L<restart docs|http://www.elastic.co/guide/en/watcher/current/api-rest-restart.html>
+See the L<restart docs|http://www.elastic.co/guide/en/watcher/current/api-rest.html#api-rest-restart>
 for more information.
 
 =head1 AUTHOR
